Change in simtrace2[master]: firmware: octsimtest: Fix disabling the card_insert signal

This is merely a historical archive of years 2008-2021, before the migration to mailman3.

A maintained and still updated list archive can be found at https://lists.osmocom.org/hyperkitty/list/gerrit-log@lists.osmocom.org/.

laforge gerrit-no-reply at lists.osmocom.org
Thu Jun 3 13:07:06 UTC 2021


laforge has uploaded this change for review. ( https://gerrit.osmocom.org/c/simtrace2/+/24538 )


Change subject: firmware: octsimtest: Fix disabling the card_insert signal
......................................................................

firmware: octsimtest: Fix disabling the card_insert signal

Back in I8c9b0c3d862a967832134b24252577739182da62 we added support
for enabling the card_insert signal, but not for explicit disable
of it.  Let's fix that.

Change-Id: I6f32bde60674119c9912e51059a53b5ee74d074a
---
M firmware/libboard/octsimtest/source/board_octsimtest.c
1 file changed, 7 insertions(+), 2 deletions(-)



  git pull ssh://gerrit.osmocom.org:29418/simtrace2 refs/changes/38/24538/1

diff --git a/firmware/libboard/octsimtest/source/board_octsimtest.c b/firmware/libboard/octsimtest/source/board_octsimtest.c
index 1c6a278..5dff046 100644
--- a/firmware/libboard/octsimtest/source/board_octsimtest.c
+++ b/firmware/libboard/octsimtest/source/board_octsimtest.c
@@ -103,8 +103,13 @@
 	 * the sim-present signal of the respective slot */
 
 	if (mcp2317_present) {
-		/* we must enable card-presence of the active slot and disable it on all others */
-		mcp23017_set_output_a(MCP23017_ADDRESS, (1 << s));
+		if (card_insert) {
+			/* we must enable card-presence of the active slot and disable it on all others */
+			mcp23017_set_output_a(MCP23017_ADDRESS, (1 << s));
+		} else {
+			/* we disable all card insert signals */
+			mcp23017_set_output_a(MCP23017_ADDRESS, 0);
+		}
 	} else {
 		TRACE_WARNING("No MCP23017 present; cannot set CARD_INSERT\r\n");
 	}

-- 
To view, visit https://gerrit.osmocom.org/c/simtrace2/+/24538
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings

Gerrit-Project: simtrace2
Gerrit-Branch: master
Gerrit-Change-Id: I6f32bde60674119c9912e51059a53b5ee74d074a
Gerrit-Change-Number: 24538
Gerrit-PatchSet: 1
Gerrit-Owner: laforge <laforge at osmocom.org>
Gerrit-MessageType: newchange
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.osmocom.org/pipermail/gerrit-log/attachments/20210603/8bd6685f/attachment.htm>


More information about the gerrit-log mailing list